import axios from 'axios';
import {customAlphabet} from 'nanoid';

export const isArraySame = async (array1: any, array2: any) => {
    const is_same =
        array1.length === array2.length &&
        array2.every(function (id: any, index: any) {
            return id === array1[index];
        });

    return is_same;
};

export const generateNewNanoId = async (isOnlyNumber: any) => {
    let alphabetCombination = '1234567890abcdef';
    if (isOnlyNumber === true) {
        alphabetCombination =
            '0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ';
    }
    const nanoid = customAlphabet(alphabetCombination, 8);
    return 'hymanfashion' + nanoid();
};

export const generateOrderId = async (ordersData: any) => {
    let arr = [];
    if (ordersData.length > 0) {
        for (let data = 0; data < ordersData.length; data++) {
            console.log(ordersData[data]["orderId"]);
            let orderId = ordersData[data]["orderId"].split('GC-');
            arr.push(parseInt(orderId[1]))
        }
        let maxOrderID = Math.max(...arr) + 1;
        return "GC-" + maxOrderID;
    } else {
        return "GC-1000";
    }
};

export const generateStockId = async (stockData: any) => {
    let arr = [];
    if (stockData.length > 0) {
        for (let data = 0; data < stockData.length; data++) {
            let orderId = stockData[data]['StockID'].split('hymanfashion');
            arr.push(parseInt(orderId[1]));
        }
        let maxOrderID = Math.max(...arr) + 1;
        return 'hymanfashion' + maxOrderID;
    } else {
        return 'hymanfashion1000';
    }
};

export function generateRandomPassword(passwordLength: number) {
    var numberChars = '0123456789';
    var upperChars = 'ABCDEFGHIJKLMNOPQRSTUVWXYZ';
    var lowerChars = 'abcdefghijklmnopqrstuvwxyz';
    var allChars = numberChars + upperChars + lowerChars;
    var randPasswordArray = Array(passwordLength);
    randPasswordArray[0] = numberChars;
    randPasswordArray[1] = upperChars;
    randPasswordArray[2] = lowerChars;
    randPasswordArray = randPasswordArray.fill(allChars, 3);
    return shuffleArray(
        randPasswordArray.map(function (x) {
            return x[Math.floor(Math.random() * x.length)];
        }),
    ).join('');
}

function shuffleArray(array: any[]) {
    for (var i = array.length - 1; i > 0; i--) {
        var j = Math.floor(Math.random() * (i + 1));
        var temp = array[i];
        array[i] = array[j];
        array[j] = temp;
    }
    return array;
}

export const validateGoogleCapcha = async (token: any) => {
    const response = await axios.post(
        `https://www.google.com/recaptcha/api/siteverify?secret=${process.env.GOOGLE_RECAPCHA_SECRET}&response=${token}`,
    );
    return response['data'];
};

export function sleepFor(sleepDuration) {
    var now = new Date().getTime();
    while (new Date().getTime() < now + sleepDuration) {
        /* Do nothing */
    }
}

export function formattedDateString(date: any) {
    const year = new Date(date).toLocaleString('default', {year: 'numeric'});

    const month = new Date(date).toLocaleString('default', {month: '2-digit'});

    const day = new Date(date).toLocaleString('default', {day: '2-digit'});

    return day + '/' + month + '/' + year;
}

export function urlSlug(title: any) {
    let slug: any;

    // Convert to lower case
    slug = title.toLowerCase();

    // Remove special characters
    slug = slug.replace(/\`|\~|\!|\@|\#|\||\$|\%|\^|\&|\*|\(|\)|\+|\=|\,|\?|\>|\<|\'|\"|\:|\;|_/gi, '');

    // Replace spaces with dash symbols
    slug = slug.replace(/ /gi, "-");

    // Replace forward slash with dash symbols
    slug = slug.replace(/\//gi, "-");

    // Replace dot with dash symbols
    slug = slug.replace(/\./gi, "-");

    // Remove consecutive dash symbols 
    slug = slug.replace(/\-\-\-\-\-/gi, '-');
    slug = slug.replace(/\-\-\-\-/gi, '-');
    slug = slug.replace(/\-\-\-/gi, '-');
    slug = slug.replace(/\-\-/gi, '-');

    // Remove the unwanted dash symbols at the beginning and the end of the slug
    slug = '@' + slug + '@';
    slug = slug.replace(/\@\-|\-\@|\@/gi, '');

    return slug;
}

export function convertBase64ToImage(base64String: string) {
    let base64Image = base64String.split(';base64,').pop();
    let imageBuffer = Buffer.from(base64Image, 'base64');
    return imageBuffer;
}


export function convertBase64ToPDF(base64String) {
    // Extract PDF data from base64 string
    let base64PDF = base64String.split(';base64,').pop();
    let pdfBuffer = Buffer.from(base64PDF, 'base64');
    return pdfBuffer;
}
