import {
    Body,
    Controller,
    Get,
    HttpCode,
    HttpStatus,
    Post,
    UploadedFiles,
    UseGuards,
    UseInterceptors
} from "@nestjs/common";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";
import { Constants } from "src/utils/constants";
import { FileFieldsInterceptor } from "@nestjs/platform-express";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { AboutPageOpenSourceCommunitySectionCmsService } from "./about-page-open-source-community-section-cms.service";
import { UpdateAboutPageOpenSourceCommunitySectionCmsDto } from "./dto/update-about-page-open-source-community-section-cms.dto";

@Controller({ path: "about-page-open-source-community-section-cms", version: Constants.API_VERSION_1 })

export class AboutPageOpenSourceCommunitySectionCmsController {
    constructor(private readonly service: AboutPageOpenSourceCommunitySectionCmsService) { }

    @Post()
    @HttpCode(HttpStatus.OK)
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
        [
            { name: "image", maxCount: 1 }
        ]
    ))
    updateOrCreateData(
        @Body() dto: UpdateAboutPageOpenSourceCommunitySectionCmsDto,
        @UploadedFiles() files: {
            image: UploadedMulterFileI
        }
    ) {
        return this.service.updateOrCreateData(dto, files);
    }

    @Get()
    @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }
}
