import { Body, Controller, Delete, Get, Param, Patch, Post, UseGuards } from "@nestjs/common";
import { Constants } from "src/utils/constants";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";
import { UploadedFiles, UseInterceptors } from "@nestjs/common/decorators";
import { FileFieldsInterceptor } from "@nestjs/platform-express";
import { UploadedMulterFileI } from "../../SpacesModule/SpacesService";
import { CreateSocialLinksDto } from "./dto/create-social-links.dto";
import { UpdateSocialLinksDto } from "./dto/update-social-links.dto";
import { SocialLinksService } from "./social-links.service";

@Controller({ path: "social-links", version: Constants.API_VERSION_1 })

export class SocialLinksController {
    constructor(private readonly service: SocialLinksService) {
    }

    @Post()
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
        [
            { name: "icon", maxCount: 1 }
        ]
    ))
    create(
        @Body() dto: CreateSocialLinksDto,
        @UploadedFiles() files: {
            icon: UploadedMulterFileI
        }
    ) {
        return this.service.create(dto, files);
    }

    @Get()
    @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }

    @Get(":id")
    @UseGuards(AdminAuthGuard)
    findOne(@Param("id") id: string) {
        return this.service.findOne(id);
    }

    @Patch("/:id")
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
        [
            { name: "icon", maxCount: 1 }
        ]
    ))
    update(
        @Param("id") id: string,
        @Body() dto: UpdateSocialLinksDto,
        @UploadedFiles() files: {
            icon: UploadedMulterFileI
        }) {
        return this.service.update(id, dto, files);
    }

    @Delete(":id")
    @UseGuards(AdminAuthGuard)
    async remove(@Param("id") id: string) {
        return await this.service.remove(id);
    }
}
