import { Injectable } from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';
import { OrderRepository } from '../orders/order/order-repository';
import { ProductsRepository } from '../product/product/product.repository';
import { UsersRepository } from '../users/user.repository';
import { BlogPostRepository } from '../blog-post/blog-post.repository';


@Injectable()
export class DashboardService {
  constructor(
    @InjectRepository(ProductsRepository)
    private readonly productRepository: ProductsRepository,
    @InjectRepository(UsersRepository)
    private readonly userRepository: UsersRepository,
    @InjectRepository(OrderRepository)
    private readonly orderRepository: OrderRepository,
    @InjectRepository(BlogPostRepository)
    private readonly blogPostRepository: BlogPostRepository,
  ) { }

  async getAdminDashboardData() {
    const totalProducts = await this.productRepository.countProduct();
    const totalCustomers = await this.userRepository.countCustomer(3);
    const totalOrders = await this.orderRepository.countOrder();
    const totalDeliveredOrders = await this.orderRepository.countOrderWithDeliveryStatus('DELIVERED');
    const totalCancelledOrders = await this.orderRepository.countOrderWithDeliveryStatus('CANCELLED');
    const totalPendingOrders = await this.orderRepository.countOrderWithDeliveryStatus('PENDING');
    const todayProducts = await this.productRepository.todayProducts();
    const todaysOrders = await this.orderRepository.todaysOrders();
    const monthlyCustomerData = await this.userRepository.monthlyCustomer();
    const topThreeProducts = await this.productRepository.topProducts();
    const totalBlogs = await this.blogPostRepository.countAllBlogs();

    const responseData = {
      totalProducts: totalProducts,
      totalCustomers: totalCustomers,
      totalOrders: totalOrders,
      totalDeliveredOrders: totalDeliveredOrders,
      totalCancelledOrders: totalCancelledOrders,
      totalPendingOrders: totalPendingOrders,
      todayProducts: todayProducts,
      topThreeProducts: topThreeProducts,
      monthlyCustomer: {
        labels: ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec'],
        data: [
          monthlyCustomerData[0],
          monthlyCustomerData[1],
          monthlyCustomerData[2],
          monthlyCustomerData[3],
          monthlyCustomerData[4],
          monthlyCustomerData[5],
          monthlyCustomerData[6],
          monthlyCustomerData[7],
          monthlyCustomerData[8],
          monthlyCustomerData[9],
          monthlyCustomerData[10],
          monthlyCustomerData[11]]
      },
      totalBlogs: totalBlogs,
      todaysOrders: todaysOrders,
    };

    return responseData;
  }

  async getCustomerDashboardData(user: any): Promise<any | Error> {
    const totalOrders = await this.orderRepository.countUserOrder(user.id);
    const totalDeliveredOrders = await this.orderRepository.countUserOrderStatus(user.id, 'DELIVERED');
    const totalCancelledOrders = await this.orderRepository.countUserOrderStatus(user.id, 'CANCELLED');
    const totalShippedOrders = await this.orderRepository.countUserOrderStatus(user.id, 'SHIPPED');
    const totalPendingOrders = await this.orderRepository.countUserOrderStatus(user.id, 'PENDING');

    const responseData = {
      totalOrders: totalOrders ? totalOrders : 0,
      totalDeliveredOrders: totalDeliveredOrders ? totalDeliveredOrders : 0,
      totalCancelledOrders: totalCancelledOrders ? totalCancelledOrders : 0,
      totalShippedOrders: totalShippedOrders ? totalShippedOrders : 0,
      totalPendingOrders: totalPendingOrders ? totalPendingOrders : 0,
    }

    return responseData;
  }
}
